(-main & args)(add-to-map m [t g])(is-mane-kept? mane-kept line)(is-mane? [g t])(select-mane-trans)Formats the step hash-map and spits it to the step's output file. The step hash-map holds all data about the step, and that's what your protocol uses to decide what to do. Valuable step data includes: :cmds The step's commands (a.k.a., body), as a sequence, one element per line :inputs All input files specified by the step :outputs All output files specified by the step :opts All options specified by the step, as a hash-map
Formats the step hash-map and spits it to the step's output file. The step hash-map holds all data about the step, and that's what your protocol uses to decide what to do. Valuable step data includes: :cmds The step's commands (a.k.a., body), as a sequence, one element per line :inputs All input files specified by the step :outputs All output files specified by the step :opts All options specified by the step, as a hash-map
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |